"use strict";
/**
 * Base communication layer for the SharePoint Framework
 *
 * @remarks
 * This package defines the base communication layer for
 * the SharePoint Framework.  For REST calls, it handles authentication,
 * logging, diagnostics, and batching.  It also simplifies requests by
 * adding default headers that follow the recommended best practices.
 *
 * @packagedocumentation
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SPHttpHeader = exports.SPHttpClientResponse = exports.SPHttpClientConfiguration = exports.SPHttpClientCommonConfiguration = exports.SPHttpClientBatchConfiguration = exports.SPHttpClientBatch = exports._SPHttpClientHelper = exports.SPHttpClient = exports.ODataVersion = exports.DigestCache = exports.DEPRECATED_DO_NOT_USE_OAuthTokenProvider = exports._AadTokenProviders = exports.AadTokenProviderFactory = exports.TokenAcquisitionEventArgs = exports.AadTokenProvider = exports.BeforeRedirectEventArgs = exports.PopupEventArgs = exports._AadConstants = exports.HttpClientResponse = exports.HttpClientConfiguration = exports._HttpClientHelper = exports.HttpClient = exports._fetchProviderServiceKey = exports._GraphHttpClientContext = exports._getPrefetchDataProviderServiceKey = exports._PrefetchDataProviderService = exports._CacheStrategy = exports._CacheKeyType = exports._CacheManager = exports._getCacheDataProviderServiceKey = exports._CacheDataProviderService = exports.AadHttpClientResponse = exports.AadHttpClientFactory = exports.AadHttpClientConfiguration = exports.AadHttpClient = void 0;
var AadHttpClient_1 = require("./aadHttpClient/AadHttpClient");
Object.defineProperty(exports, "AadHttpClient", { enumerable: true, get: function () { return __importDefault(AadHttpClient_1).default; } });
var AadHttpClientConfiguration_1 = require("./aadHttpClient/AadHttpClientConfiguration");
Object.defineProperty(exports, "AadHttpClientConfiguration", { enumerable: true, get: function () { return __importDefault(AadHttpClientConfiguration_1).default; } });
var AadHttpClientFactory_1 = require("./aadHttpClient/AadHttpClientFactory");
Object.defineProperty(exports, "AadHttpClientFactory", { enumerable: true, get: function () { return __importDefault(AadHttpClientFactory_1).default; } });
var AadHttpClientResponse_1 = require("./aadHttpClient/AadHttpClientResponse");
Object.defineProperty(exports, "AadHttpClientResponse", { enumerable: true, get: function () { return __importDefault(AadHttpClientResponse_1).default; } });
var CacheDataProviderService_1 = require("./caching/CacheDataProviderService");
Object.defineProperty(exports, "_CacheDataProviderService", { enumerable: true, get: function () { return CacheDataProviderService_1.CacheDataProviderService; } });
Object.defineProperty(exports, "_getCacheDataProviderServiceKey", { enumerable: true, get: function () { return CacheDataProviderService_1.getCacheDataProviderServiceKey; } });
var CacheManager_1 = require("./caching/CacheManager");
Object.defineProperty(exports, "_CacheManager", { enumerable: true, get: function () { return CacheManager_1.CacheManager; } });
var ICacheData_1 = require("./caching/ICacheData");
var ICacheDataProvider_1 = require("./caching/ICacheDataProvider");
Object.defineProperty(exports, "_CacheKeyType", { enumerable: true, get: function () { return ICacheDataProvider_1.CacheKeyType; } });
var IClientCachableResponse_1 = require("./caching/IClientCachableResponse");
var IRequestCacheOptions_1 = require("./caching/IRequestCacheOptions");
Object.defineProperty(exports, "_CacheStrategy", { enumerable: true, get: function () { return IRequestCacheOptions_1.CacheStrategy; } });
var IPrefetchData_1 = require("./prefetch/IPrefetchData");
var IPrefetchDataProvider_1 = require("./prefetch/IPrefetchDataProvider");
var PrefetchDataProviderService_1 = require("./prefetch/PrefetchDataProviderService");
Object.defineProperty(exports, "_PrefetchDataProviderService", { enumerable: true, get: function () { return PrefetchDataProviderService_1.PrefetchDataProviderService; } });
Object.defineProperty(exports, "_getPrefetchDataProviderServiceKey", { enumerable: true, get: function () { return PrefetchDataProviderService_1.getPrefetchDataProviderServiceKey; } });
var GraphHttpClientContext_1 = require("./graphHttpClient/GraphHttpClientContext");
Object.defineProperty(exports, "_GraphHttpClientContext", { enumerable: true, get: function () { return __importDefault(GraphHttpClientContext_1).default; } });
var FetchProvider_1 = require("./httpClient/FetchProvider");
Object.defineProperty(exports, "_fetchProviderServiceKey", { enumerable: true, get: function () { return FetchProvider_1.fetchProviderServiceKey; } });
var HttpClient_1 = require("./httpClient/HttpClient");
Object.defineProperty(exports, "HttpClient", { enumerable: true, get: function () { return __importDefault(HttpClient_1).default; } });
var HttpClientHelper_1 = require("./httpClient/HttpClientHelper");
Object.defineProperty(exports, "_HttpClientHelper", { enumerable: true, get: function () { return __importDefault(HttpClientHelper_1).default; } });
var HttpClientConfiguration_1 = require("./httpClient/HttpClientConfiguration");
Object.defineProperty(exports, "HttpClientConfiguration", { enumerable: true, get: function () { return __importDefault(HttpClientConfiguration_1).default; } });
var HttpClientResponse_1 = require("./httpClient/HttpClientResponse");
Object.defineProperty(exports, "HttpClientResponse", { enumerable: true, get: function () { return __importDefault(HttpClientResponse_1).default; } });
var AadConstants_1 = require("./oauthTokenProvider/AadConstants");
Object.defineProperty(exports, "_AadConstants", { enumerable: true, get: function () { return __importDefault(AadConstants_1).default; } });
var AadTokenProvider_1 = require("./oauthTokenProvider/AadTokenProvider");
Object.defineProperty(exports, "PopupEventArgs", { enumerable: true, get: function () { return AadTokenProvider_1.PopupEventArgs; } });
Object.defineProperty(exports, "BeforeRedirectEventArgs", { enumerable: true, get: function () { return AadTokenProvider_1.BeforeRedirectEventArgs; } });
Object.defineProperty(exports, "AadTokenProvider", { enumerable: true, get: function () { return __importDefault(AadTokenProvider_1).default; } });
Object.defineProperty(exports, "TokenAcquisitionEventArgs", { enumerable: true, get: function () { return AadTokenProvider_1.TokenAcquisitionEventArgs; } });
var AadTokenProviderFactory_1 = require("./oauthTokenProvider/AadTokenProviderFactory");
Object.defineProperty(exports, "AadTokenProviderFactory", { enumerable: true, get: function () { return __importDefault(AadTokenProviderFactory_1).default; } });
var AadTokenProviders_1 = require("./oauthTokenProvider/AadTokenProviders");
Object.defineProperty(exports, "_AadTokenProviders", { enumerable: true, get: function () { return __importDefault(AadTokenProviders_1).default; } });
var IAadTokenProvider_1 = require("./oauthTokenProvider/IAadTokenProvider");
var ITokenProvider_1 = require("./oauthTokenProvider/ITokenProvider");
var DEPRECATED_DO_NOT_USE_OAuthTokenProvider_1 = require("./oauthTokenProvider/DEPRECATED_DO_NOT_USE_OAuthTokenProvider");
Object.defineProperty(exports, "DEPRECATED_DO_NOT_USE_OAuthTokenProvider", { enumerable: true, get: function () { return __importDefault(DEPRECATED_DO_NOT_USE_OAuthTokenProvider_1).default; } });
var DigestCache_1 = require("./spHttpClient/DigestCache");
Object.defineProperty(exports, "DigestCache", { enumerable: true, get: function () { return __importDefault(DigestCache_1).default; } });
var IDigestCache_1 = require("./spHttpClient/IDigestCache");
var ODataVersion_1 = require("./spHttpClient/ODataVersion");
Object.defineProperty(exports, "ODataVersion", { enumerable: true, get: function () { return __importDefault(ODataVersion_1).default; } });
var SPHttpClient_1 = require("./spHttpClient/SPHttpClient");
Object.defineProperty(exports, "SPHttpClient", { enumerable: true, get: function () { return __importDefault(SPHttpClient_1).default; } });
var SPHttpClientHelper_1 = require("./spHttpClient/SPHttpClientHelper");
Object.defineProperty(exports, "_SPHttpClientHelper", { enumerable: true, get: function () { return __importDefault(SPHttpClientHelper_1).default; } });
var SPHttpClientBatch_1 = require("./spHttpClient/SPHttpClientBatch");
Object.defineProperty(exports, "SPHttpClientBatch", { enumerable: true, get: function () { return __importDefault(SPHttpClientBatch_1).default; } });
var SPHttpClientBatchConfiguration_1 = require("./spHttpClient/SPHttpClientBatchConfiguration");
Object.defineProperty(exports, "SPHttpClientBatchConfiguration", { enumerable: true, get: function () { return __importDefault(SPHttpClientBatchConfiguration_1).default; } });
var SPHttpClientCommonConfiguration_1 = require("./spHttpClient/SPHttpClientCommonConfiguration");
Object.defineProperty(exports, "SPHttpClientCommonConfiguration", { enumerable: true, get: function () { return __importDefault(SPHttpClientCommonConfiguration_1).default; } });
var SPHttpClientConfiguration_1 = require("./spHttpClient/SPHttpClientConfiguration");
Object.defineProperty(exports, "SPHttpClientConfiguration", { enumerable: true, get: function () { return __importDefault(SPHttpClientConfiguration_1).default; } });
var SPHttpClientResponse_1 = require("./spHttpClient/SPHttpClientResponse");
Object.defineProperty(exports, "SPHttpClientResponse", { enumerable: true, get: function () { return __importDefault(SPHttpClientResponse_1).default; } });
var SPHttpHeader_1 = require("./spHttpClient/SPHttpHeader");
Object.defineProperty(exports, "SPHttpHeader", { enumerable: true, get: function () { return SPHttpHeader_1.SPHttpHeader; } });
//# sourceMappingURL=index.js.map